@@ -29,7 +29,7 @@ class Crawler:
         if list_href.count == 0 or not list_href: return None
         list_href.map(lambda x: x.url())
         list_href.forEach(lambda x: Terminal.found(x))
-        responses = self.fetcher.get_all_pages(list_href)
+        responses = self.fetcher.get_all_pages(list_href.contents)
         responses.removeErrors()
         return responses
     
